@@ -8,7 +8,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ('all' => [ qw(new get_info make_report)]);
 our @EXPORT_OK = (@{$EXPORT_TAGS{'all'}});
 our @EXPORT = qw();
-our $VERSION ='1.2';
+our $VERSION ='1.3';
 #####################################################
 my ($class, $this, $router);
 #####################################################
@@ -32,21 +32,23 @@ sub get_info(){
         $_ =~ s/cM//g;
         $_ =~ s/\r//g;
         if (/^interface/ .. /^!/){
-            if ($_ =~ /interface/){
+            if ($_ =~ /^interface/){
              @split1 = split " ", $_;
              $interface = $split1[1];
              $description = '';
              $address = '';
             }
-            if ($_ =~ /description/){
+            if ($_ =~ /^ description/){
                 $description = $_;
+                $description =~ s/^ description //;
             }
-            if ($_ =~ /ip address/){
+            if (($_ =~ /^ ip address/) or ($_ =~ /^ no ip address/) or ($_ =~ /^ ip unnumbered/)){
                 @split2 = split " ", $_;
-                $address = "$split2[2];$split2[3]" if $split2[3];
-                $address = "no ipv4 address;no mask" if !$split2[3];
-                $this->{"Interface ".$interface.";"} = "$address;no description\n" if !$description;
-                $this->{"Interface ".$interface.";"} = "$address;$description\n" if $description;
+                $address = "$split2[2]-->$split2[3]" if $split2[3];
+                $address =~ s/\s//g;
+                $address = "No IPv4 address-->No mask" if !$split2[3];
+                $this->{"Interface-->".$interface."-->"} = "$address-->No description\n" if !$description;
+                $this->{"Interface-->".$interface."-->"} = "$address-->$description\n" if $description;
             }
         }
     }
